\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ClassHal}[2016/03/25 v1.0]
\LoadClassWithOptions{article}
\ProcessOptions\relax

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% More counters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{etex}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Margins
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage[left=2.5cm,right=2.5cm,top=1.75cm,bottom=2cm]{geometry}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% page de titre
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand*\mtsavedim[1]{%
\expandafter\edef\csname mt#1\endcsname{\expandafter\the\csname#1\endcsname}}
\newcommand*\mtrestoredim[1]{%
\global\csname#1\endcsname=\csname mt#1\endcsname}

\renewcommand\maketitle{%
\mtsavedim{topmargin}%
\mtsavedim{headheight}%
\mtsavedim{headsep}%
\mtsavedim{textheight}%
\edef\mtbottom{\Gm@bmargin}%
\edef\mttop{\Gm@tmargin}%
\edef\mtleft{\Gm@lmargin}%
\edef\mtright{\Gm@rmargin}%
\newgeometry{left=\mtleft,right=\mtright,top=0pt,bottom=\mtbottom}%
\begingroup%
\fboxsep=0pt\fboxrule=0pt\parindent=0pt%
\hspace{-\Gm@lmargin}%
\colorbox{ColorDoc!5}{%
\makebox[\paperwidth][l]{%
\hspace{\Gm@lmargin}%
\parbox{\textwidth}{%
\@maketitle%
\hspace{-\Gm@lmargin}\color{ColorDoc}\rule{\paperwidth}{3pt}}}}%
\endgroup}%

\let\mt@outputpage\@outputpage%
\def\@outputpage{%
\mt@outputpage%
\mtrestoredim{topmargin}%
\mtrestoredim{headheight}%
\mtrestoredim{headsep}%
\mtrestoredim{textheight}%
\global \@colht \textheight}%

\def\@maketitle{%
 \vskip\mttop%
 \begin{center}%
 \color{ColorDoc}%
   {\Large\bfseries\sffamily\@title\par}%
   \vskip .125in%
   {\normalsize\sffamily\@author}%
  \end{center}\par%
 }%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% reformater la table des matières
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%\setcounter{tocdepth}{3}
%\renewcommand\@pnumwidth{1.55em}
%\renewcommand\@tocrmarg {2.55em}
%\renewcommand\@dotsep{4.5}

\RequirePackage{titletoc}%
\contentsmargin{0cm}%
\titlecontents{section}[0cm]%
 {\vskip-1pt\color{ColorDoc}\bfseries\sffamily\small}%
 {\makebox[.5cm][l]{\color{ColorDoc}\thecontentslabel\enspace}}
 {}%
 {\hfill\thecontentspage}%
 []%
\titlecontents{subsection}[0cm]%
 {\vskip-1pt\color{ColorDoc}\sffamily\small}%
 {\makebox[.5cm][l]{\color{ColorDoc}\thecontentslabel\enspace}}
 {}%
 {\;\titlerule*[.5pc]{.}\;\thecontentspage}%
 []%

\renewcommand\tableofcontents{
\@starttoc{toc}%\vskip-5pt%
\noindent{\color{ColorDoc}\rule{\textwidth}{1pt}}\par\vskip\topsep%
}
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Look of section and subsections
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setcounter{secnumdepth}{3}
\RequirePackage[calcwidth]{titlesec}
\titlespacing*{\section}{0pt}{2\topsep}{2ex}
\titlespacing*{\subsection}{0pt}{1.5\topsep}{2ex}
\titlespacing*{\subsubsection}{0pt}{\topsep}{2ex}

\titleformat{\section}[runin]
{\color{ColorDoc}\bfseries\large\sffamily}
{\makebox[0pt][r]{\makebox[\Gm@lmargin][r]{\smash{\rule[-3mm]{5mm}{1cm}}\hfill\smash{\huge\thesection.}\hskip5pt}}}
{0em}
{}
[]

\titleformat{\subsection}[runin]
{\color{ColorDoc}\bfseries\large\sffamily}
{\makebox[0pt][r]{\makebox[\Gm@lmargin][r]{\smash{{\color{ColorDoc!50}\rule[-2mm]{3mm}{8mm}}}\hfill\smash{\large\thesubsection.}\hskip5pt}}}
{0em}
{}
[]

\titleformat{\subsubsection}[runin]
{\color{ColorDoc}\bfseries\sffamily}
{\makebox[0pt][r]{\makebox[\Gm@lmargin][r]{\smash{{\color{ColorDoc!50}\rule[-3mm]{2mm}{1cm}}}\hfill\smash{\normalsize\thesubsection.}\hskip5pt}}}
{0em}
{}
[]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Abstract and keywords
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewenvironment{abstract}{%
     \if@twocolumn%
       \section*{Abstract}%
     \else%
\list{}{%
	\footnotesize%
	\itemsep\z@%
	\labelwidth 3.8pc%
	\itemindent 0pt%
	\labelsep 0.5pc%
	\parsep \topsep%
	\listparindent 1pc%
	\leftmargin 3.8pc%
	\item[\color{ColorDoc}\scshape\bfseries\sffamily\abstractname]}%
    \fi%
}{\if@twocolumn\else\endlist\vskip.5\topsep\fi}%

\newenvironment{@abssec}[1]{%
     \if@twocolumn%
       \section*{#1}%
     \else%
       \vskip.5\topsep%
	   \footnotesize%
       \parindent 0in%
       \hangindent 3.8pc%
%		\hangindent 0pc
         {\color{ColorDoc}\scshape\bfseries\sffamily #1\hspace*{.5pc}}\ignorespaces%
     \fi}%
     {\if@twocolumn\else\par\vskip.5\topsep\fi}%

\newcommand\keywordsname{Keywords}
\newenvironment{keywords}{\begin{@abssec}{\keywordsname}}{\end{@abssec}\par
\vskip-6pt\noindent\color{ColorDoc}\rule{\textwidth}{1pt}\par\vskip.5\topsep}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lengths
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength\arraycolsep{5\p@}
\setlength\tabcolsep{6\p@}
\setlength\arrayrulewidth{.4\p@}
\setlength\doublerulesep{2\p@}
\setlength\tabbingsep{\labelsep}
\skip\@mpfootins = \skip\footins
\setlength\fboxsep{3\p@}
\setlength\fboxrule{.4\p@}
\setlength\abovecaptionskip{5\p@}
\setlength\belowcaptionskip{0\p@}
\AtBeginDocument{%
%\setlength\abovedisplayskip{0.5\abovedisplayskip}
%\setlength\belowdisplayskip{0.5\belowdisplayskip}
%\setlength\abovedisplayshortskip{0.5\abovedisplayshortskip}
%\setlength\belowdisplayshortskip{0.5\belowdisplayshortskip}
\setlength\parskip{0pt}
\flushbottom
}
\setlength\columnsep{10\p@}
\setlength\columnseprule{0\p@}

\newlength\mymarginleft
\setlength\mymarginleft{\Gm@lmargin}
\newlength\mymarginleftinner
\setlength\mymarginleftinner{\Gm@lmargin}
\addtolength\mymarginleftinner{-2mm}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Footnotes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%\renewcommand\footnoterule{%
%  \kern-3\p@
%  \hrule width \textwidth
%  \kern 2.6\p@}
%\long\def\@makefntext#1{%
%    \parindent .25in%
%    \noindent
%    \hbox to .25in{\hss\@makefnmark}#1}

\long\def\@makefntext#1{%
    \parindent 0em%
    \noindent
    \hb@xt@0em{\llap{\@makefnmark\,}}#1}
	
\pagestyle{plain}
\pagenumbering{arabic}      % Arabic page numbers

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\RequirePackage[dvips]{graphics,graphicx}
\RequirePackage{graphicx}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Bibliography
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%\usepackage{cite}
\RequirePackage[
maxnames=7,
url=false,
%isbn=false,
autolang=hyphen,     % ajuster les césure pour chaque entrée
hyperref=true,    % les liens hypertexte, c'est le Bien
abbreviate=false,    % pas d'abréviation
backend=biber,
style=numeric-comp,
]{biblatex} 
\renewcommand{\bibfont}{\normalfont\footnotesize}
\defbibheading{bibempty}{}  		% voir ci-dessous

%\DeclareFieldFormat[article]{titlecase}{\MakeSentenceCase{#1}}
%\DeclareFieldFormat[article]{journaltitle}{\MakeSentenceCase{#1}}

\DeclareFieldFormat{titlecase}{\MakeTitleCase{#1}}

\newrobustcmd{\MakeTitleCase}[1]{%
 \ifthenelse{\ifcurrentfield{booktitle}\OR\ifcurrentfield{booksubtitle}%
 \OR\ifcurrentfield{maintitle}\OR\ifcurrentfield{mainsubtitle}%
 \OR\ifcurrentfield{journaltitle}\OR\ifcurrentfield{journalsubtitle}%
 \OR\ifcurrentfield{issuetitle}\OR\ifcurrentfield{issuesubtitle}%
 \OR\ifentrytype{book}\OR\ifentrytype{mvbook}\OR\ifentrytype{bookinbook}%
 \OR\ifentrytype{booklet}\OR\ifentrytype{suppbook}%
 \OR\ifentrytype{collection}\OR\ifentrytype{mvcollection}%
 \OR\ifentrytype{suppcollection}\OR\ifentrytype{manual}%
 \OR\ifentrytype{periodical}\OR\ifentrytype{suppperiodical}%
 \OR\ifentrytype{proceedings}\OR\ifentrytype{mvproceedings}%
 \OR\ifentrytype{reference}\OR\ifentrytype{mvreference}%
 \OR\ifentrytype{report}\OR\ifentrytype{thesis}}
 {#1}
 {\MakeSentenceCase{#1}}}

\DefineBibliographyStrings{english}{page={},pages={}}%
\DeclareFieldFormat[article, incollection, unpublished]{pages}{#1}
\renewcommand*{\bibpagespunct}{\addcolon}

% first author Family name first
\DeclareNameAlias{author}{last-first/first-last}

%clears month
\AtEveryBibitem{\clearfield{month}}
\AtEveryCitekey{\clearfield{month}}
\AtEveryBibitem{\clearfield{issue}} 
\AtEveryBibitem{\clearfield{issn}} 
% clears language
\AtEveryBibitem{\clearfield{note}}
% clears notes
\AtEveryBibitem{\ifentrytype{book}{\clearlist{location}}{}}  	% clears notes

% gestion du numéro de volume entre parenthèses
\renewbibmacro*{volume+number+eid}{%
 \iffieldundef{volume}
 {}
 {\printfield{volume}%
 \printfield[parens]{number}%
 \setunit{\addcolon}%
 \printfield{eid}}}

\renewbibmacro*{journal+issuetitle}{%
 \usebibmacro{journal}%
 \setunit*{\addspace}%
 \iffieldundef{series}
  {}
  {\newunit
   \printfield{series}%
   \setunit{\addspace}}%
 \setunit{\addspace}%
 %\usebibmacro{issue}%
 %\setunit{\addcomma\space}%
 \usebibmacro{volume+number+eid}%
 %\setunit{\addcomma\space}%
 %\usebibmacro{date}%
 %\newunit
 } 
 
\DeclareBibliographyDriver{article}{%
 \usebibmacro{bibindex}%
 \usebibmacro{begentry}%
 \usebibmacro{author/translator+others}%
 \setunit{\labelnamepunct}\newblock
 \usebibmacro{title}%
 \newunit
 \printlist{language}%
 \newunit\newblock
 \usebibmacro{byauthor}%
 \newunit\newblock
 \usebibmacro{bytranslator+others}%
 \newunit\newblock
 \printfield{version}%
 \newunit\newblock
 \usebibmacro{in:}%
 \usebibmacro{journal+issuetitle}%
 \newunit
 \usebibmacro{byeditor+others}%
 \newunit
 \usebibmacro{note+pages}%
 %\newunit
 \setunit{\addcomma\space}
 \usebibmacro{date}%
 \setunit{\adddot\par\nobreak}
 \iftoggle{bbx:isbn}
 {\printfield{issn}}
 {}%
\newunit\newblock
 \usebibmacro{doi+eprint+url}%
 \newunit\newblock
 \usebibmacro{addendum+pubstate}%
 \setunit{\bibpagerefpunct}\newblock
 \usebibmacro{pageref}%
 \newunit\newblock
 \iftoggle{bbx:related}
 {\usebibmacro{related:init}%
  \usebibmacro{related}}
 {}%
 \usebibmacro{finentry}}

\renewbibmacro{in:}{}
\renewbibmacro*{doi+eprint+url}{%
 %\setunit{\adddot\par\nobreak}
 \iftoggle{bbx:doi}
 {\printfield{doi}}
 {}%
 %\newunit\newblock
 \iftoggle{bbx:eprint}
 {\usebibmacro{eprint}}
 {}}

\renewbibmacro*{eprint}{%
 %\setunit{\adddot\par\nobreak}% Added
 \iffieldundef{eprinttype}
 {\printfield{eprint}}
 {\printfield[eprint:\strfield{eprinttype}]{eprint}}}
	
\renewbibmacro*{url+urldate}{%
 \setunit{\adddot\par\nobreak}% Added
 \printfield{url}%
 \iffieldundef{urlyear}
 {}
 {\setunit*{\addspace}\printtext[urldate]{\printurldate}}}

% gestion des liens hal dans la bibliographie
\def\oaitourl#1{http://hal.archives-ouvertes.fr/#1}
\DeclareFieldFormat{eprint:oai}{%
\ifhyperref{\textcolor{ColorDoc}{[\href{\oaitourl#1}{\nolinkurl{#1}}]}}{\nolinkurl{#1}}
}

% gestion des liens DOI dans la bibliographie
\DeclareFieldFormat{doi}{%
 %\newline
 %\mkbibacro{DOI}\addcolon\space
  \ifhyperref
   {\textcolor{ColorDoi}{[\href{http://dx.doi.org/#1}{\nolinkurl{#1}}]}}
   {\nolinkurl{#1}}}

% gestion des liens hal dans la bibliographie
\def\arktourl#1{http://gallica.bnf.fr/#1}
\DeclareFieldFormat{eprint:ark}{%
\ifhyperref{\textcolor{ColorDoc}{[\href{\arktourl#1}{\nolinkurl{#1}}]}}{\nolinkurl{#1}}
}

\DeclareFieldFormat{isbn}{\color{red!50!black}\sffamily[\mkbibacro{ISBN}~\addcolon\space #1]}

% test l'existence de eprint et indique doi sinon
\DeclareSourcemap{
 \maps[datatype=bibtex]{
  \map{
   \step[fieldsource=eprint,final]
   \step[fieldset=doi,null]
  } 
 }
}

% petites capitales pour les noms de famille
\renewcommand*{\mkbibnamefamily}[1]{\ifmknamesc{\textsc{#1}}{#1}}
%\renewcommand*{\mkbibnamegiven}[1]{\ifmknamesc{\textsc{#1}}{#1}}
\renewcommand*{\mkbibnameprefix}[1]{%
 \ifboolexpr{ test {\ifmknamesc} and test {\ifuseprefix} }
 {\textsc{#1}}
 {#1}}

\def\ifmknamesc{%
 \ifboolexpr{ test {\ifcurrentname{labelname}}
    or test {\ifcurrentname{author}}
    or ( test {\ifnameundef{author}} and test {\ifcurrentname{editor}} ) }}

\AtBeginBibliography{%
 \renewcommand*{\finalnamedelim}{\addcomma\space}%
}

\DeclareFieldFormat
 [article]
 {journaltitle}{#1}
\DeclareFieldFormat
 [article]
 {title}{\textit{#1}} 
\DeclareFieldFormat
 [book]
 {title}{\textit{#1}}

\defbibenvironment{bibliography}%
 {\list%
 {\printtext[labelnumberwidth]{%
	\printfield{prefixnumber}%
	\printfield{labelnumber}}}
  {\setlength{\labelwidth}{\labelnumberwidth}%
	\setlength{\bibitemsep}{0pt}%
	\setlength{\labelsep}{5pt}%
	\setlength{\itemindent}{-.75\labelwidth}%
  \setlength{\leftmargin}{\labelsep+\labelwidth-\itemindent}%
  %\setlength{\labelsep}{.5\biblabelsep}%
  %\addtolength{\leftmargin}{\labelsep}%
  \setlength{\itemsep}{\bibitemsep}%
  \setlength{\parsep}{\bibparsep}}%
  \renewcommand*{\makelabel}[1]{\hss##1}}%
{\endlist}%
{\item}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\RequirePackage[colorlinks,pdfmark,dvips]{hyperref}
\RequirePackage[hidelinks]{hyperref}
\urlstyle{sf}
\RequirePackage[numbered]{bookmark}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Environements mathématiques
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{amsmath,amsfonts,amsthm}
\RequirePackage{mdframed}
\def\@endtheorem{\endtrivlist}		% NEW
\newtheoremstyle{plainT}				% name
{0pt}	% Space above
{0pt}	% Space below
{\itshape}							% Body font
{}									% Indent amount
{\bfseries\sffamily}				% Theorem head font
{}									% Punctuation after theorem head
{.5em}								% Space after theorem head
{\color{ColorDoc}\thmname{#1}\thmnumber{ #2}\thmnote{ [#3]}}

\newtheoremstyle{plain}				% name
{\topsep}	% Space above
{\topsep}	% Space below
{\itshape}							% Body font
{}									% Indent amount
{\bfseries\sffamily}				% Theorem head font
{}									% Punctuation after theorem head
{.5em}								% Space after theorem head
{\color{ColorDoc}\thmname{#1}\thmnumber{ #2}\thmnote{ [#3]}}

\newtheoremstyle{remark}			% name
{\topsep}	% Space above
{\topsep}	% Space below
{}									% Body font
{}									% Indent amount
{\itshape}							% Theorem head font
{.}									% Punctuation after theorem head
{.5em}								% Space after theorem head
{}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\qedsymbol}{{\color{ColorDoc}\footnotesize$\blacksquare$}}
\renewenvironment{proof}[1][\bfseries\proofname]{\par\pushQED{\qed}%
\normalfont\small\topsep6\p@\@plus6\p@\relax%
 %\trivlist %%%% old
\list{}{\leftmargin=\parindent%
   \rightmargin=0pt%
   \settowidth{\itemindent}{\bfseries#1}%
   \labelwidth=\itemindent%
   \parsep=0pt%
   \listparindent=\parindent}%
\item[\hskip\labelsep\itshape #1\@addpunct{.}\ ]\ignorespaces%
}{\popQED%
%\endtrivlist %%OLD
\endlist %%NEW
\@endpefalse}%

\numberwithin{equation}{section}%

\newmdenv[hidealllines=true,leftline=true,
skipabove=1.5\topsep,skipbelow=\topsep,
innertopmargin=0em,%
innerbottommargin=0em,%
innerrightmargin=0em,%
rightmargin=0em,%
innerleftmargin=\mymarginleftinner,%
leftmargin=-\mymarginleft,%
linewidth=2mm,%
linecolor=gray!50]{markleft}

\theoremstyle{plainT}
\newtheorem{theoremT}{Theorem}[section]
\newenvironment{theorem}{\begin{markleft}\begin{theoremT}}{\end{theoremT}\end{markleft}}

\theoremstyle{plain}
\newtheorem{lemma}[theoremT]{Lemma}
\newtheorem{proposition}[theoremT]{Proposition}
\newtheorem{definition}{Definition}[section]
\newtheorem{corollary}{Corollary}[section]
\newtheorem{assumption}{Assumption}[section]

\theoremstyle{remark}
\newtheorem{remark}{Remark}[section]


\endinput
%% End of file ClassHal.cls.
